package com.huijy.management.service.impl;

import java.util.List;
import com.huijy.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.huijy.management.mapper.MemberEvaluateMapper;
import com.huijy.management.domain.MemberEvaluate;
import com.huijy.management.service.IMemberEvaluateService;

/**
 * 会员评价Service业务层处理
 *
 * @author luobo
 * @date 2021-09-12
 */
@Service
public class MemberEvaluateServiceImpl implements IMemberEvaluateService
{
    @Autowired
    private MemberEvaluateMapper memberEvaluateMapper;

    /**
     * 查询会员评价
     *
     * @param memberEvaluateId 会员评价主键
     * @return 会员评价
     */
    @Override
    public MemberEvaluate selectMemberEvaluateByMemberEvaluateId(Long memberEvaluateId)
    {
        return memberEvaluateMapper.selectMemberEvaluateByMemberEvaluateId(memberEvaluateId);
    }

    /**
     * 查询会员评价列表
     *
     * @param memberEvaluate 会员评价
     * @return 会员评价
     */
    @Override
    public List<MemberEvaluate> selectMemberEvaluateList(MemberEvaluate memberEvaluate)
    {
        return memberEvaluateMapper.selectMemberEvaluateList(memberEvaluate);
    }

    /**
     * 新增会员评价
     *
     * @param memberEvaluate 会员评价
     * @return 结果
     */
    @Override
    public int insertMemberEvaluate(MemberEvaluate memberEvaluate)
    {
        memberEvaluate.setCreateTime(DateUtils.getNowDate());
        return memberEvaluateMapper.insertMemberEvaluate(memberEvaluate);
    }

    /**
     * 修改会员评价
     *
     * @param memberEvaluate 会员评价
     * @return 结果
     */
    @Override
    public int updateMemberEvaluate(MemberEvaluate memberEvaluate)
    {
        return memberEvaluateMapper.updateMemberEvaluate(memberEvaluate);
    }

    /**
     * 批量删除会员评价
     *
     * @param memberEvaluateIds 需要删除的会员评价主键
     * @return 结果
     */
    @Override
    public int deleteMemberEvaluateByMemberEvaluateIds(Long[] memberEvaluateIds)
    {
        return memberEvaluateMapper.deleteMemberEvaluateByMemberEvaluateIds(memberEvaluateIds);
    }

    /**
     * 删除会员评价信息
     *
     * @param memberEvaluateId 会员评价主键
     * @return 结果
     */
    @Override
    public int deleteMemberEvaluateByMemberEvaluateId(Long memberEvaluateId)
    {
        return memberEvaluateMapper.deleteMemberEvaluateByMemberEvaluateId(memberEvaluateId);
    }
}
